@@ -43,6 +43,7 @@ module Network.AWS.CodeDeploy.GetDeploymentGroup
     , gdgrDeploymentGroupInfo
     ) where
 
+import Network.AWS.Data (Object)
 import Network.AWS.Prelude
 import Network.AWS.Request.JSON
 import Network.AWS.CodeDeploy.Types
@@ -69,8 +70,8 @@ getDeploymentGroup p1 p2 = GetDeploymentGroup
     , _gdgDeploymentGroupName = p2
     }
 
--- | The name of an existing AWS CodeDeploy application within the AWS user
--- account.
+-- | The name of an existing AWS CodeDeploy application associated with the
+-- applicable IAM user or AWS account.
 gdgApplicationName :: Lens' GetDeploymentGroup Text
 gdgApplicationName =
     lens _gdgApplicationName (\s a -> s { _gdgApplicationName = a })
